@@ -29,12 +29,14 @@
 #include "dbusconnection.h"
 #include "dbuserror.h"
 #include "dbuserrorutils.h"
+#include "dbusinterfacevtable.h"
 #include "dbusintrospection.h"
 #include "dbusmessage.h"
 #include "dbusmethodinvocation.h"
 #include "dbusownname.h"
 #include "dbusproxy.h"
 #include "dbusserver.h"
+#include "dbussubtreevtable.h"
 #include "dbusutils.h"
 #include "dbuswatchname.h"
 #include "drive.h"
